import cgi
import os

print "Content-type: text/html"
print
print cgi.FieldStorage()
print '<p>query string ',os.environ['QUERY_STRING']